---
name: Documentation or notebooks
about: Let us know what would make the GeometricKernels documentation better
---

# Documentation/tutorial notebooks

*Is there anything missing in the docs?*

*Are there any mistakes in the docs?*

*Is there a feature that needs some example code in a notebook?*

*Do you know how to fix the docs?* If so, it'd be amazing if you'd be willing to directly contribute a pull request :)


Links:
* [latest GeometricKernels documentation](https://geometric-kernels.github.io/GeometricKernels/index.html)
* [Landing page](https://geometric-kernels.github.io/)